@@ -11,42 +11,43 @@
  ***************************************************************************/
 
 void two_D_dwt(double *X, int *M, int *N, int *L, double *h, double *g, 
-	       double *LL, double *LH, double *HL, double *HH)
+         double *LL, double *LH, double *HL, double *HH)
 {
-  int i, j, k;
+ 
+ 
+ 
+  int i, j, k,jj;
   double *data, *Wout, *Vout, *Low, *High;
   
-  /*
-   *  Perform one-dimensional DWT on columns (length M).
-   */
   
+   //  Perform one-dimensional DWT on columns (length M).
+   
+  
+ 
   Wout = (double *) malloc((*M) * sizeof(double));
-  Vout = (double *) malloc((*M) * sizeof(double));
+  Vout = (double *) malloc((*M) * sizeof(double)); 
   
-  /*
-   *  Create temporary "matrices" to store DWT of columns.
-   */
+   //  Create temporary "matrices" to store DWT of columns.
   Low = (double *) malloc((*N*(*M/2)) * sizeof(double));
   High = (double *) malloc((*N*(*M/2)) * sizeof(double));
+ 
   
   for(i = 0; i < *N; i++) {
-    /*
-     *  Must take column from X and place into vector for DWT.
-     */
+     //  Must take column from X and place into vector for DWT.
     data = (double *) malloc((*M) * sizeof(double));
     for(j = 0; j < *M; j++) {
       data[j] = X[i*(*M)+j];
-      /* printf("X[%d][%d] = %f\n", i, j, X[i*(*M)+j]); */
+      //printf("X[%d][%d] = %f\n", i, j, X[i*(*M)+j]);
     }
-    /*
-     *  Perform DWT and read into temporary matrices.
-     */
+    
+    //Perform DWT and read into temporary matrices.
     dwt(data, M, L, h, g, Wout, Vout);
     for(k = 0; k < (int) *M/2; k++) {
+      
       Low[i*(*M/2)+k] = Vout[k]; 
       High[i*(*M/2)+k] = Wout[k];
-      /* printf("Low[%d][%d] = %f\n", i, k, Low[i*(*M/2)+k]);
-	 printf("High[%d][%d] = %f\n", i, k, High[i*(*M/2)+k]); */
+      // printf("Low[%d][%d] = %f\n", i, k, Low[i*(*M/2)+k]);
+       //printf("High[%d][%d] = %f\n", i, k, High[i*(*M/2)+k]); 
     }
     free(data);
   }
@@ -54,59 +55,78 @@ void two_D_dwt(double *X, int *M, int *N, int *L, double *h, double *g,
   free(Wout);
   free(Vout);
   
-  /*
-   *  Perform one-dimensional DWT on rows (length N).
-   */
+ 
+  
+   //  Perform one-dimensional DWT on rows (length N).
+   
   
   Wout = (double *) malloc((*N) * sizeof(double));
   Vout = (double *) malloc((*N) * sizeof(double));
-  
+ 
+ 
+   
+ 
   for(i = 0; i < (int) *M/2; i++) {
-    /*
-     *  Must take row from "Low" and place into vector for DWT.
-     */
+    
+     // Must take row from "Low" and place into vector for DWT.
+     
     data = (double *) malloc((*N) * sizeof(double));
     for(j = 0; j < *N; j++) {
       data[j] = Low[i+j*(*M/2)];
-      /* printf("Low[%d][%d] = %f\n", i, j, Low[i+j*(*M/2)]); */
+      // printf("Low[%d][%d] = %f\n", i, j, Low[i+j*(*M/2)]); 
     }
-    /*
-     *  Perform DWT and read into final "Low" matrices.
-     */
+    
+    
+    
+    //  Perform DWT and read into final "Low" matrices.
+    
+
+ 
     dwt(data, N, L, h, g, Wout, Vout);
     for(k = 0; k < (int) *N/2; k++) {
-      LL[i+k*(*N/2)] = Vout[k]; 
-      HL[i+k*(*N/2)] = Wout[k];
-      /* printf("LL[%d][%d] = %f\n", i, k, LL[i+k*(*N/2)]);
-	 printf("LH[%d][%d] = %f\n", i, k, HL[i+k*(*N/2)]); */
+      
+      LL[i+k*(*M/2)] = Vout[k]; 
+      HL[i+k*(*M/2)] = Wout[k]; 
+      
+      //LL[i+k*(*N/2)] = Vout[k]; // Original ones
+      //HL[i+k*(*N/2)] = Wout[k]; // Original ones
+     // printf("LL[%d][%d] = %f\n", i, k, LL[i+k*(*N/2)]);
+        // printf("LH[%d][%d] = %f\n", i, k, HL[i+k*(*N/2)]); 
     }
     free(data);
-    
-    /*
-     *  Must take row from "High" and place into vector for DWT.
-     */
+
+
+
+     //Must take row from "High" and place into vector for DWT.
     data = (double *) malloc((*N) * sizeof(double));
     for(j = 0; j < *N; j++) {
       data[j] = High[i+j*(*M/2)];
-      /* printf("High[%d][%d] = %f\n", j, i, High[i+j*(*M/2)]); */
+      // printf("High[%d][%d] = %f\n", j, i, High[i+j*(*M/2)]); 
     }
-    /*
-     *  Perform DWT and read into final "High" matrices.
-     */
+    
+    //  Perform DWT and read into final "High" matrices.
     dwt(data, N, L, h, g, Wout, Vout);
     for(k = 0; k < (int) *N/2; k++) {
-      LH[i+k*(*N/2)] = Vout[k]; 
-      HH[i+k*(*N/2)] = Wout[k];
-      /* printf("HL[%d][%d] = %f\n", i, k, LH[i+k*(*N/2)]);
-	 printf("HH[%d][%d] = %f\n", i, k, HH[i+k*(*N/2)]); */
-    }
+      
+      LH[i+k*(*M/2)] = Vout[k]; 
+      HH[i+k*(*M/2)] = Wout[k];
+      
+      //LH[i+k*(*N/2)] = Vout[k]; //Original ones
+      //HH[i+k*(*N/2)] = Wout[k]; //Original ones
+  // printf("HL[%d][%d] = %f\n", i, k, LH[i+k*(*N/2)]);
+  // printf("HH[%d][%d] = %f\n", i, k, HH[i+k*(*N/2)]); 
+    } 
+    
     free(data);
   }
   
+  
+  
   free(Wout);
   free(Vout);
   free(Low);
   free(High);
+  
 }
 
 /***************************************************************************
@@ -118,7 +138,6 @@ void two_D_dwt(double *X, int *M, int *N, int *L, double *h, double *g,
 void printdvec(double *v, int n)
 { 
   int i;
-
   for(i = 0; i <= n-1; i++)
     printf("%f ", v[i]);
   printf("\n");
@@ -131,7 +150,7 @@ void printdvec(double *v, int n)
  ***************************************************************************/
 
 void two_D_idwt(double *LL, double *LH, double *HL, double *HH, int *M, 
-		int *N, int *L, double *h, double *g, double *image)
+		       int *N, int *L, double *h, double *g, double *image)
 {
   int i, j, k;
   /*
@@ -216,7 +235,7 @@ void two_D_idwt(double *LL, double *LH, double *HL, double *HH, int *M,
  ***************************************************************************/
 
 void two_D_modwt(double *X, int *M, int *N, int *J, int *L, double *h, 
-		 double *g, double *LL, double *LH, double *HL, double *HH)
+			 double *g, double *LL, double *LH, double *HL, double *HH)
 {
   int i, j, k, index;
   /*
@@ -258,9 +277,9 @@ void two_D_modwt(double *X, int *M, int *N, int *J, int *L, double *h,
       Low[index] = Vout[k]; 
       High[index] = Wout[k];
       /*
-       *	if(debug) {
-       *	printf("Low[%d][%d] = %f\n", i, k, Low[index]);
-       *	printf("High[%d][%d] = %f\n", i, k, High[index]);
+      *if(debug) {
+      *printf("Low[%d][%d] = %f\n", i, k, Low[index]);
+      *printf("High[%d][%d] = %f\n", i, k, High[index]);
        *        }
        */
     }
@@ -296,9 +315,9 @@ void two_D_modwt(double *X, int *M, int *N, int *J, int *L, double *h,
       LL[index] = Vout[k]; 
       LH[index] = Wout[k];
       /*
-       *	if(debug) {
-       *	printf("LL[%d][%d] = %f\n", i, k, LL[index]);
-       *	printf("LH[%d][%d] = %f\n", i, k, LH[index]);
+      *if(debug) {
+      *printf("LL[%d][%d] = %f\n", i, k, LL[index]);
+      *printf("LH[%d][%d] = %f\n", i, k, LH[index]);
        *        }
        */
     }
@@ -322,9 +341,9 @@ void two_D_modwt(double *X, int *M, int *N, int *J, int *L, double *h,
       HL[index] = Vout[k]; 
       HH[index] = Wout[k];
       /* 
-       *	 if(debug) {
-       *	 printf("HL[%d][%d] = %f\n", i, k, HL[index]);
-       *	 printf("HH[%d][%d] = %f\n", i, k, HH[index]);
+      * if(debug) {
+      * printf("HL[%d][%d] = %f\n", i, k, HL[index]);
+      * printf("HH[%d][%d] = %f\n", i, k, HH[index]);
        *         }
        */
     }
@@ -344,8 +363,8 @@ void two_D_modwt(double *X, int *M, int *N, int *J, int *L, double *h,
  ***************************************************************************/
 
 void two_D_imodwt(double *LL, double *LH, double *HL, double *HH, int *M, 
-		  int *N, int *J, int *L, double *h, double *g, 
-		  double *image)
+			   int *N, int *J, int *L, double *h, double *g, 
+			     double *image)
 {
   int i, j, k, index;
   double *Win, *Vin, *Low, *High, *Xout;
@@ -425,3 +444,4 @@ void two_D_imodwt(double *LL, double *LH, double *HL, double *HH, int *M,
   free(Low);
   free(High);
 }
+
